# gwchirp

Gravitational Waveforms in python

pypi - https://pypi.org/project/gw-chirpy/

## Installation

```
pip install gw-chirpy
```

### Setup env

```
conda env create -f environment.yaml
```

 - I did `conda create -n chirpy-dev python=3.11` then `conda/pip install` other deps.
 - Save environment with `conda env export > environment.yaml`
